// java wrapper for vtkPath object
//

package vtk;
import vtk.*;

public class vtkPath extends vtkPointSet
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native void InsertNextPoint_3(double id0[],int id1);
  public void InsertNextPoint(double id0[],int id1)
    { InsertNextPoint_3(id0,id1); }

  private native void InsertNextPoint_4(double id0,double id1,double id2,int id3);
  public void InsertNextPoint(double id0,double id1,double id2,int id3)
    { InsertNextPoint_4(id0,id1,id2,id3); }

  private native void SetCodes_5(vtkIntArray id0);
  public void SetCodes(vtkIntArray id0)
    { SetCodes_5(id0); }

  private native long GetCodes_6();
  public vtkIntArray GetCodes() {
    long temp = GetCodes_6();

    if (temp == 0) return null;
    return (vtkIntArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfCells_7();
  public int GetNumberOfCells()
    { return GetNumberOfCells_7(); }

  private native long GetCell_8(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_8(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_9(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_9(id0,id1); }

  private native int GetCellType_10(int id0);
  public int GetCellType(int id0)
    { return GetCellType_10(id0); }

  private native void GetCellPoints_11(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_11(id0,id1); }

  private native void GetPointCells_12(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_12(id0,id1); }

  private native int GetMaxCellSize_13();
  public int GetMaxCellSize()
    { return GetMaxCellSize_13(); }

  private native void Allocate_14(int id0,int id1);
  public void Allocate(int id0,int id1)
    { Allocate_14(id0,id1); }

  private native void Reset_15();
  public void Reset()
    { Reset_15(); }

  private native long GetData_16(vtkInformation id0);
  public vtkPath GetData(vtkInformation id0) {
    long temp = GetData_16(id0);

    if (temp == 0) return null;
    return (vtkPath)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_17(vtkInformationVector id0,int id1);
  public vtkPath GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_17(id0,id1);

    if (temp == 0) return null;
    return (vtkPath)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCell_18(int id0,int id1,int id2);
  public vtkCell GetCell(int id0,int id1,int id2) {
    long temp = GetCell_18(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPath() { super(); }

  public vtkPath(long id) { super(id); }
  public native long   VTKInit();

}
